==> tslint-4.0.2.jar: META-INF/resources/webjars/tslint/4.0.2/lib/index.d.ts <==
/**
 * @license
 * Copyright 2013 Palantir Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as Configuration from "./configuration";
import * as Formatters from "./formatters";
import { RuleFailure } from "./language/rule/rule";
import * as Linter from "./linter";
import * as Rules from "./rules";
import * as Test from "./test";
import * as Utils from "./utils";
export { Configuration, Formatters, Linter, Rules, Test, Utils };
export * from "./language/rule/rule";
export * from "./enableDisableRules";
export * from "./formatterLoader";
export * from "./ruleLoader";
export * from "./language/utils";
export * from "./language/languageServiceHost";
export * from "./language/walker";
export * from "./language/formatter/formatter";
export interface LintResult {
    failureCount: number;
    failures: RuleFailure[];
    fixes?: RuleFailure[];
    format: string | Function;
    output: string;
}
export interface ILinterOptions {
    fix: boolean;
    formatter?: string | Function;
    formattersDirectory?: string;
    rulesDirectory?: string | string[];
}

==> tslint-4.5.1.jar: META-INF/resources/webjars/tslint/4.5.1/lib/index.d.ts <==
/**
 * @license
 * Copyright 2013 Palantir Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as Configuration from "./configuration";
import * as Formatters from "./formatters";
import { RuleFailure } from "./language/rule/rule";
import * as Linter from "./linter";
import * as Rules from "./rules";
import * as Test from "./test";
import * as Utils from "./utils";
export { Configuration, Formatters, Linter, Rules, Test, Utils };
export * from "./language/rule/rule";
export * from "./enableDisableRules";
export * from "./formatterLoader";
export * from "./ruleLoader";
export * from "./language/utils";
export * from "./language/languageServiceHost";
export * from "./language/walker";
export * from "./language/formatter/formatter";
export interface LintResult {
    failureCount: number;
    failures: RuleFailure[];
    fixes?: RuleFailure[];
    format: string | FormatterFunction;
    output: string;
}
export declare type FormatterFunction = (failures: RuleFailure[]) => string;
export interface ILinterOptions {
    fix: boolean;
    formatter?: string | FormatterFunction;
    formattersDirectory?: string;
    rulesDirectory?: string | string[];
}
